@@ -950,6 +950,30 @@ class DesignManager extends Core
 		$buttonTag = '<a' . $idAttr . $urlAttr . ' class="' . $tagClass . '" role="button" data-container="body"' . $otherAttr . '><i class="glyphicon ' . $iconType . '"></i></a>';
 		return $buttonTag;
 	}
+	/**
+	 * 情報リンクを作成
+	 *
+	 * @param string $url		リンク先(リンク先がない場合は空文字列)
+	 * @param string $title		ツールチップ用文字列
+	 * @param string $tagId		タグのID
+	 * @param string $attr		その他の追加属性
+	 * @param string $btnClass	ボタンのカラークラス
+	 * @return string 			ボタンのタグ
+	 */
+	function createInfoLink($url, $title = '', $btnClass = 'btn-default')
+	{
+		if (empty($url)){
+			$url = 'javascript:void(0);';
+		} else {
+			$url = convertUrlToHtmlEntity($this->getUrl($url));
+		}
+
+		$otherAttr = '';
+		if (!empty($title)) $otherAttr .= ' rel="m3help" title="' . $title . '"';
+
+		$buttonTag = '<a href="' . $url . '" target="_blank" role="button" data-container="body"' . $otherAttr . '><i class="glyphicon glyphicon-info-sign"></i></a>';
+		return $buttonTag;
+	}
 	/**
 	 * カレンダーによる期間入力フィールドを作成
 	 *
@@ -989,5 +1013,23 @@ class DesignManager extends Core
 		$tag .= '<div class="col-sm-2 m3config_item" style="width:110px;"><input type="text" class="form-control" id="' . $endTimeId . '" name="' . $endTimeId . '" value="' . convertToHtmlEntity($endTimeValue) . '" maxlength="10" /></div>';
 		return $tag;
 	}
+	/**
+	 * ユーザアバターを作成
+	 *
+	 * @param string $userName			ユーザ名
+	 * @param string $avatar			アバター画像名
+	 * @param string $linkUrl			リンク先
+	 * @param int $size					画像サイズ
+	 * @return string 					アバターHTML
+	 */
+	function createUserAvatar($userName, $avatar, $size, $linkUrl = '')
+	{
+		$avatarUrl = $this->gInstance->getImageManager()->getAvatarUrl($avatar);
+		$imageSize = intval($size);
+		$iconTitle = convertUrlToHtmlEntity($userName);
+		$iconTag = '<img class="avatar" src="' . $this->getUrl($avatarUrl) . '" width="' . $imageSize . '" height="' . $imageSize . '" alt="' . $iconTitle . '" title="' . $iconTitle . '" rel="m3help" />';
+		if (!empty($linkUrl)) $iconTag ='<a href="' . convertUrlToHtmlEntity($this->getUrl($linkUrl)) . '">' . $iconTag . '</a>';
+		return $iconTag;
+	}
 }
 ?>
