@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2015 Magic3 Project.
+ * @copyright  Copyright 2006-2017 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -28,7 +28,10 @@ class admin_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 	const CALENDAR_CSS_FILE = '/jscalendar-1.0/calendar-win2k-1.css';		// カレンダー用CSSファイル
 	
 	// 画面
-	const TASK_TEST				= 'test';			// テスト画面
+	const TASK_TEMPLIST			= 'templist';				// テンプレート一覧
+	const TASK_TEMPIMAGE		= 'tempimage';				// テンプレート画像編集
+	const TASK_TEMPIMAGE_DETAIL	= 'tempimage_detail';		// テンプレート画像編集(詳細)
+	const TASK_TEST				= 'test';					// テスト画面
 	
 	/**
 	 * コンストラクタ
